Struct
GUPnPServiceStateVariableInfo
Description [src]
struct GUPnPServiceStateVariableInfo {
char* name;
gboolean send_events;
gboolean is_numeric;
GType type;
GValue default_value;
GValue minimum;
GValue maximum;
GValue step;
utf8 allowed_values;
}
This structure contains information about service state variable.
Structure members
name:char*The name of the state variable.
send_events:gbooleanWhether this state variable can source events.
is_numeric:gbooleanWether this state variable is a numeric type (integer and float).
type:GTypeThe GType of this state variable.
default_value:GValueThe default value of this state variable.
minimum:GValueThe minimum value of this state variable. Only applies to numeric data types.
maximum:GValueThe maximum value of this state variable. Only applies to numeric data types.
step:GValueThe step value of this state variable. Only applies to numeric data types.
allowed_values:utf8The allowed values of this state variable. Only applies to string data types. Unlike the other fields in this structure, this field contains a list of (char *) strings rather than GValues.